Change feed | Django site admin

# Django administration

Welcome, eric. Documentation / Change password / Log out

# Change feed

- History

Feed url:
Name:
Shortname:
Is active

If disabled, this feed will not be further updated.

Feed image: Currently: feeds/favicon.png
Change:

## Fields updated automatically by Feedjack

Title:
Tagline: Latest entries on Weblog
Link:
Etag:
Last modified:

Date:
Time:

Last checked:

Date:
Time:

Delete